@@ -2,7 +2,6 @@
 
 Functions:
 
-- [get_ids_dataframe][duqtools.api.get_ids_dataframe]
 - [rebase_on_grid][duqtools.api.rebase_on_grid]
 - [rebase_on_time][duqtools.api.rebase_on_time]
 
@@ -19,11 +18,10 @@ Plotting:
 """
 
 from ._plot_utils import alt_errorband_chart, alt_line_chart
-from .ids import (IDSMapping, ImasHandle, Variable, get_ids_dataframe,
-                  rebase_on_grid, rebase_on_time)
+from .ids import IDSMapping, ImasHandle, rebase_on_grid, rebase_on_time
+from .schema import IDSVariableModel as Variable
 
 __all__ = [
-    'get_ids_dataframe',
     'rebase_on_grid',
     'rebase_on_time',
     'ImasHandle',
