@@ -2,14 +2,15 @@ from typing import Dict, Sequence
 
 import xarray as xr
 
+from ..config import cfg
 from ..operations import add_to_op_queue
-from ..schema import VariableModel
+from ..schema import IDSVariableModel
 from ._handle import ImasHandle
 from ._rebase import rebase_on_time, standardize_grid
 
 
-def _get_placeholder_dim(grid_var: VariableModel,
-                         time_var: VariableModel) -> str:
+def _get_placeholder_dim(grid_var: IDSVariableModel,
+                         time_var: IDSVariableModel) -> str:
     dims = [dim for dim in grid_var.dims if dim != time_var.name]
 
     if len(dims) != 1:
@@ -18,7 +19,7 @@ def _get_placeholder_dim(grid_var: VariableModel,
     return dims[0]
 
 
-def raise_if_ids_inconsistent(*variables: VariableModel):
+def raise_if_ids_inconsistent(*variables: IDSVariableModel):
     idss = {var.ids for var in variables}
     if len(idss) != 1:
         raise ValueError('Variables must have the same IDS, '
@@ -29,10 +30,17 @@ def raise_if_ids_inconsistent(*variables: VariableModel):
 def merge_data(
     source_data: Dict[str, ImasHandle],
     target: ImasHandle,
-    time_var: VariableModel,
-    grid_var: VariableModel,
-    data_vars: Sequence[VariableModel],
+    time_var: str,
+    grid_var: str,
+    data_vars: Sequence[str],
 ):
+
+    time_var = cfg.variables.to_variable_dict()[time_var]
+    grid_var = cfg.variables.to_variable_dict()[grid_var]
+    data_vars = [
+        cfg.variables.to_variable_dict()[data_var] for data_var in data_vars
+    ]
+
     raise_if_ids_inconsistent(time_var, grid_var, *data_vars)
 
     TIME_DIM = time_var.name
@@ -47,7 +55,8 @@ def merge_data(
 
     # pick first time step as basis
     GRID_DIM = grid_var.name
-    grid_dim_data = target_data_map.get_with_replace(grid_var.path, time=0)
+
+    grid_dim_data = target_data_map.get_at_index(grid_var, 0)
     time_dim_data = target_data_map[time_var.path]
 
     datasets = []
@@ -83,9 +92,9 @@ def merge_data(
             mean = means.isel({TIME_DIM: i})[var.name].data
             stdev = stdevs.isel({TIME_DIM: i})[var.name].data
 
-            target_data_map.set_with_replace(var.path, value=mean, time=i)
-            target_data_map.set_with_replace(var.path + '_error_upper',
-                                             value=mean + stdev,
-                                             time=i)
+            target_data_map.set_at_index(var.path, value=mean, index=i)
+            target_data_map.set_at_index(var.path + '_error_upper',
+                                         value=mean + stdev,
+                                         index=i)
 
     target_data_map.sync(target)
