@@ -1,12 +1,29 @@
-from typing import List
+from typing import List, Optional
 
 from pydantic import Field
 
 from ._basemodel import BaseModel
 from ._description_helpers import formatter as f
+from ._jetto import JettoVar
 
 
-class VariableModel(BaseModel):
+class JettoVariableModel(BaseModel):
+    """Variable for describing variables specific to Jetto, The lookup table
+    can be defined as a JettoVar under the lookup key."""
+
+    type: str = Field('jetto-variable',
+                      description='discriminator for the variable type')
+
+    name: str = Field(description=f("""
+        Name of the variable
+        Used for the lookup table to find actual fields
+        """))
+    lookup: Optional[JettoVar] = Field(description=f("""
+    description of the fields that have to be updated for a Jetto Variable
+    """))
+
+
+class IDSVariableModel(BaseModel):
     """Variable for describing data within a IMAS database.
 
     The variable can be given a name, which will be used in the rest of the config
@@ -19,10 +36,11 @@ class VariableModel(BaseModel):
 
     The IDS path may contain indices. You can point to a single index, by simply giving the
     complete path (i.e. `profiles_1d/0/t_i_average` for the 0th time slice).
-    To retrieve all time slices, you can use `profiles_1d/$time/t_i_average`.
-    Any part of the path may be indexed by prefixing that part by a dollar sign. To indicate
-    the time index, we used `...\\$time\\...`.
+    To retrieve all time slices, you can use `profiles_1d/*/t_i_average`.
     """
+    type: str = Field('IDS-variable',
+                      description='discriminator for the variable type')
+
     name: str = Field(description=f("""
         Name of the variable.
         This will be used to reference this variable.
