@@ -1,15 +1,16 @@
 from getpass import getuser
 from pathlib import Path
-from typing import Dict, List, Union
+from typing import List, Union
 
-from pydantic import DirectoryPath, Field, root_validator
+from pydantic import DirectoryPath, Field
 from typing_extensions import Literal
 
 from ._basemodel import BaseModel
 from ._description_helpers import formatter as f
-from ._dimensions import IDSOperationDim
+from ._dimensions import CoupledDim, OperationDim
 from ._imas import ImasBaseModel
-from ._variable import VariableModel
+from ._jetto import JettoVar
+from ._variable import IDSVariableModel, JettoVariableModel
 from .data_location import DataLocation
 from .matrix_samplers import (CartesianProduct, HaltonSampler, LHSSampler,
                               SobolSampler)
@@ -17,23 +18,24 @@ from .workdir import WorkDirectoryModel
 
 
 class VariableConfigModel(BaseModel):
-    __root__: List[VariableModel] = Field([
-        VariableModel(name='rho_tor_norm',
-                      ids='core_profiles',
-                      path='profiles_1d/$time/grid/rho_tor_norm',
-                      dims=['x']),
-        VariableModel(name='t_i_average',
-                      ids='core_profiles',
-                      path='profiles_1d/$time/t_i_average',
-                      dims=['x']),
-        VariableModel(name='zeff',
-                      ids='core_profiles',
-                      path='profiles_1d/$time/zeff',
-                      dims=['x']),
-        VariableModel(name='time',
-                      ids='core_profiles',
-                      path='time',
-                      dims=['time']),
+    __root__: List[Union[JettoVariableModel, IDSVariableModel]] = Field([
+        IDSVariableModel(name='rho_tor_norm',
+                         ids='core_profiles',
+                         path='profiles_1d/*/grid/rho_tor_norm',
+                         dims=['time', 'x']),
+        IDSVariableModel(name='t_i_average',
+                         ids='core_profiles',
+                         path='profiles_1d/*/t_i_average',
+                         dims=['time', 'x']),
+        IDSVariableModel(name='zeff',
+                         ids='core_profiles',
+                         path='profiles_1d/*/zeff',
+                         dims=['time', 'x']),
+        IDSVariableModel(name='time',
+                         ids='core_profiles',
+                         path='time',
+                         dims=['time']),
+        JettoVariableModel(name='major_radius', lookup=JettoVar()),
     ])
 
     def __iter__(self):
@@ -50,11 +52,13 @@ class VariableConfigModel(BaseModel):
 class CreateConfigModel(BaseModel):
     """The options of the `create` subcommand are stored in the `create` key in
     the config."""
-    dimensions: List[Union[IDSOperationDim]] = Field([
-        IDSOperationDim(variable='t_i_average'),
-        IDSOperationDim(variable='zeff')
+    dimensions: List[Union[CoupledDim, OperationDim]] = Field([
+        OperationDim(variable='t_i_average'),
+        OperationDim(variable='zeff'),
+        OperationDim(
+            variable='major_radius', values=[296, 297], operator='copyto')
     ],
-                                                     description=f("""
+                                                              description=f("""
         The `dimensions` specifies the dimensions of the matrix to sample
         from. Each dimension is a compound set of operations to apply.
         From this, a matrix all possible combinations is generated.
@@ -173,7 +177,7 @@ class MergeStep(BaseModel):
     will be used to rebase all data variables to a common grid.
 
     The time variable will be used to rebase the grid variable and the data variables
-    to a common time coordinate. To denote the time index, use `/$time/` in both
+    to a common time coordinate. To denote the time index, use `/*/` in both
     the grid and data variables.
 
     Rebasing involves interpolation.
@@ -181,24 +185,23 @@ class MergeStep(BaseModel):
     Note that multiple merge steps can be specified, for example for different
     IDS.
     """
-    data_variables: List[Union[str,
-                               VariableModel]] = Field(['t_i_average', 'zeff'],
-                                                       description=f("""
+    data_variables: List[str] = Field(['t_i_average', 'zeff'],
+                                      description=f("""
             This is a list of data variables to be merged. This means
             that the mean and error for these data over all runs are calculated
             and written back to the ouput data location.
-            The paths should contain `/$time/` for the time component.
+            The paths should contain `/*/` for the time component or other dimensions.
             """))
-    grid_variable: Union[str, VariableModel] = Field('rho_tor_norm',
-                                                     description=f("""
+    grid_variable: str = Field('rho_tor_norm',
+                               description=f("""
             This variable points to the data for the grid coordinate. It must share a common
             placeholder dimension with the data variables.
             It will be used to rebase all data variables to same (radial) grid before merging
             using interpolation.
-            The path should contain '/$time/' to denote the time component.
+            The path should contain '/*/' to denote the time component or other dimension.
             """))
-    time_variable: Union[str, VariableModel] = Field('time',
-                                                     description=f("""
+    time_variable: str = Field('time',
+                               description=f("""
             This variable determines the time coordinate to merge on. This ensures
             that the data from all runs are on the same time coordinates before
             merging.
@@ -266,40 +269,9 @@ class ConfigModel(BaseModel):
         description='Define variables for use in the subcommands.')
 
     workspace: WorkDirectoryModel = WorkDirectoryModel()
-    system: Literal['jetto',
-                    'dummy'] = Field('jetto',
-                                     description='backend system to use')
-
-    @root_validator(pre=False, skip_on_failure=True)
-    def update_variables(cls, values):
-        """Grab variable names from different steps and replace them with the
-        definitions from the `variables` attribute."""
-        var_dict = values['variables'].to_variable_dict()
-
-        def validate_variable(var: Union[str, VariableModel],
-                              dct: Dict[str, VariableModel]) -> VariableModel:
-            if isinstance(var, VariableModel):
-                return var
-
-            try:
-                variable_model = dct[var]
-            except KeyError:
-                raise KeyError(f'Variable: `{var}` has not been defined.')
-
-            return variable_model
-
-        for dimension in values['create'].dimensions:
-            dimension.variable = validate_variable(dimension.variable,
-                                                   var_dict)
-
-        for step in values['merge'].plan:
-            step.grid_variable = validate_variable(step.grid_variable,
-                                                   var_dict)
-            step.time_variable = validate_variable(step.time_variable,
-                                                   var_dict)
-            step.data_variables = [
-                validate_variable(variable, var_dict)
-                for variable in step.data_variables
-            ]
-
-        return values
+    system: Literal['jetto', 'dummy', 'jetto-pythontools',
+                    'jetto-duqtools'] = Field(
+                        'jetto', description='backend system to use')
+    quiet: bool = Field(
+        False,
+        description='dont output to stdout, except for mandatory prompts')
