@@ -1,11 +1,11 @@
 from __future__ import annotations
 
-from typing import List
+from typing import List, Union
 
 from pydantic import DirectoryPath, Field
 
 from ._basemodel import BaseModel
-from ._dimensions import IDSOperation
+from ._dimensions import IDSOperation, JettoOperation
 from ._imas import ImasBaseModel
 
 
@@ -13,7 +13,8 @@ class Run(BaseModel):
     dirname: DirectoryPath = Field(None, description='Directory of run')
     data_in: ImasBaseModel
     data_out: ImasBaseModel
-    operations: List[IDSOperation]
+    operations: List[Union[IDSOperation, JettoOperation,
+                           List[Union[IDSOperation, JettoOperation]]]]
 
 
 class Runs(BaseModel):
