@@ -1,10 +1,9 @@
 import logging
-from pathlib import Path
 from time import sleep
 
 from .config import cfg
-from .jetto import JettoSettingsManager
-from .models import WorkDirectory
+from .jettoduqtools import JettoSettingsManager
+from .models import Job, WorkDirectory
 
 logger = logging.getLogger(__name__)
 info, debug = logger.info, logger.debug
@@ -13,47 +12,15 @@ stream.setFormatter(logging.Formatter('%(message)s'))
 logger.addHandler(stream)
 
 
-def has_submit_script(dir: Path) -> bool:
-    return (dir / cfg.submit.submit_script_name).exists()
-
-
-def has_status(dir: Path) -> bool:
-    return (dir / cfg.status.status_file).exists()
-
-
-def is_submitted(dir: Path) -> bool:
-    return (dir / 'duqtools.submit.lock').exists()
-
-
-def status_file_contains(dir: Path, msg) -> bool:
-    sf = (dir / cfg.status.status_file)
-    with open(sf, 'r') as f:
-        content = f.read()
-        debug('Checking if content of %s file: %s contains %s', sf, content,
-              msg)
-        return msg in content
-
-
-def is_completed(dir: Path) -> bool:
-    return status_file_contains(dir, cfg.status.msg_completed)
-
-
-def is_failed(dir: Path) -> bool:
-    return status_file_contains(dir, cfg.status.msg_failed)
-
-
-def is_running(dir: Path) -> bool:
-    return status_file_contains(dir, cfg.status.msg_running)
-
-
 class Status():
 
-    dirs: list
-    dirs_submit: list
-    dirs_status: list
-    dirs_failed: list
-    dirs_running: list
-    dirs_unknown: list
+    jobs: list
+    jobs_submit: list
+    jobs_submitted: list
+    jobs_status: list
+    jobs_failed: list
+    jobs_running: list
+    jobs_unknown: list
 
     def __init__(self):
         debug('Submit config: %s', cfg.submit)
@@ -61,29 +28,27 @@ class Status():
         workspace = WorkDirectory.parse_obj(cfg.workspace)
         runs = workspace.runs
 
-        self.dirs = [Path(run.dirname) for run in runs]
-        debug('Case directories: %s', self.dirs)
+        self.jobs = [Job(run.dirname) for run in runs]
+        debug('Case directories: %s', self.jobs)
 
-        debug('Total number of directories: %i', len(self.dirs))
+        debug('Total number of directories: %i', len(self.jobs))
 
     def update_status(self):
 
-        self.dirs_submit = [dir for dir in self.dirs if has_submit_script(dir)]
-        self.dirs_status = [dir for dir in self.dirs if has_status(dir)]
-        self.dirs_submitted = [dir for dir in self.dirs if is_submitted(dir)]
+        self.jobs_submit = [job for job in self.jobs if job.has_submit_script]
+        self.jobs_status = [job for job in self.jobs if job.has_status]
+        self.jobs_submitted = [job for job in self.jobs if job.is_submitted]
 
-        self.dirs_completed = [
-            dir for dir in self.dirs_status if is_completed(dir)
-        ]
-        self.dirs_failed = [dir for dir in self.dirs_status if is_failed(dir)]
-        self.dirs_running = [
-            dir for dir in self.dirs_status if is_running(dir)
+        self.jobs_completed = [
+            job for job in self.jobs_status if job.is_completed
         ]
+        self.jobs_failed = [job for job in self.jobs_status if job.is_failed]
+        self.jobs_running = [job for job in self.jobs_status if job.is_running]
 
-        self.dirs_unknown = [
-            dir for dir in self.dirs_status
-            if not (dir in self.dirs_completed or dir in self.dirs_failed
-                    or dir in self.dirs_running)
+        self.jobs_unknown = [
+            job for job in self.jobs_status
+            if not (job in self.jobs_completed or job in self.jobs_failed
+                    or job in self.jobs_running)
         ]
 
     def simple_status(self):
@@ -91,36 +56,36 @@ class Status():
 
         self.update_status()
         info('Total number of directories with submission script : %i',
-             len(self.dirs_submit))
+             len(self.jobs_submit))
         info('      number of not submitted jobs                 : %i',
-             (len(self.dirs_submit) - len(self.dirs_status)))
+             (len(self.jobs_submit) - len(self.jobs_status)))
         info('Total number of directories with status     script : %i',
-             len(self.dirs_status))
+             len(self.jobs_status))
         info('Total number of directories with Completed status  : %i',
-             len(self.dirs_completed))
+             len(self.jobs_completed))
         info('Total number of directories with Failed    status  : %i',
-             len(self.dirs_failed))
+             len(self.jobs_failed))
         info('Total number of directories with Running   status  : %i',
-             len(self.dirs_running))
+             len(self.jobs_running))
         info('Total number of directories with Unknown   status  : %i',
-             len(self.dirs_unknown))
+             len(self.jobs_unknown))
 
     def progress_status(self):
         """Monitor the directory for status changes."""
         from tqdm import tqdm
-        pbar_a = tqdm(total=len(self.dirs), position=0)
+        pbar_a = tqdm(total=len(self.jobs), position=0)
         pbar_a.set_description('Submitted jobs            ...')
-        pbar_b = tqdm(total=len(self.dirs_submit), position=1)
+        pbar_b = tqdm(total=len(self.jobs_submit), position=1)
         pbar_b.set_description('Running jobs              ...')
-        pbar_c = tqdm(total=len(self.dirs_submit), position=2)
+        pbar_c = tqdm(total=len(self.jobs_submit), position=2)
         pbar_c.set_description('Completed jobs            ...')
-        pbar_d = tqdm(total=len(self.dirs_submit), position=3)
+        pbar_d = tqdm(total=len(self.jobs_submit), position=3)
         pbar_d.set_description('Failed? jobs              ...')
-        while len(self.dirs_completed) < len(self.dirs_submit):
-            pbar_a.n = len(self.dirs_submitted)
-            pbar_b.n = len(self.dirs_running)
-            pbar_c.n = len(self.dirs_completed)
-            pbar_d.n = len(self.dirs_failed) + len(self.dirs_unknown)
+        while len(self.jobs_completed) < len(self.jobs_submit):
+            pbar_a.n = len(self.jobs_submitted)
+            pbar_b.n = len(self.jobs_running)
+            pbar_c.n = len(self.jobs_completed)
+            pbar_d.n = len(self.jobs_failed) + len(self.jobs_unknown)
             pbar_a.refresh()
             pbar_b.refresh()
             pbar_c.refresh()
@@ -132,9 +97,9 @@ class Status():
         from tqdm import tqdm
         """detailed_status of all separate runs."""
         monitors = []
-        for i, dir in enumerate(self.dirs):
+        for i, job in enumerate(self.jobs):
             pbar = tqdm(total=100, position=i)
-            monitor = Monitor(pbar=pbar, dir=dir)
+            monitor = Monitor(pbar=pbar, job=job)
             monitors.append(monitor)
 
         while not all([monitor.finished for monitor in monitors]):
@@ -147,19 +112,19 @@ class Monitor():
     """Convenience class to keep track of submissions and update progress
     bars."""
 
-    def __init__(self, pbar, dir):
+    def __init__(self, pbar, job):
         self.pbar = pbar
-        self.dir = dir
+        self.job = job
         self.outfile = None
 
         self.set_status()
 
-        infile = (dir / cfg.status.in_file)
+        infile = job.in_file
         if not infile.exists():
             debug('%s does not exist, but the job is running', infile)
-            return 0
+            return
 
-        jsetmanager = JettoSettingsManager.from_directory(dir)
+        jsetmanager = JettoSettingsManager.from_directory(job.dir)
 
         self.start = jsetmanager.tstart
         self.end = jsetmanager.tend
@@ -168,25 +133,26 @@ class Monitor():
         self.finished = False
 
     def set_status(self):
-        if not (self.dir / cfg.status.status_file).exists():
+        if not self.job.has_status:
             status = 'No status'
-        elif not is_submitted(self.dir):
+        elif not self.job.is_submitted:
             status = 'Unsubmitted '
-        elif is_running(self.dir):
+        elif self.job.is_running:
             status = 'Running     '
-        elif is_failed(self.dir):
+        elif self.job.is_failed:
             status = 'FAILED      '
-        elif is_completed(self.dir):
+        elif self.job.is_completed:
             status = 'COMPLETED   '
         else:
             status = 'UNKNOWN'
 
-        self.pbar.set_description(f'{self.dir.name:8s}, status: {status:12s}')
+        self.pbar.set_description(
+            f'{self.job.dir.name:8s}, status: {status:12s}')
         self.pbar.refresh()
 
     def get_lines(self):
         if not self.outfile:
-            of = (self.dir / cfg.status.out_file)
+            of = self.job.out_file
             if not of.exists():
                 debug('%s does not exists, but the job is running', of)
                 return []
@@ -195,13 +161,13 @@ class Monitor():
 
     def update(self):
         self.set_status()
-        if (self.dir / cfg.status.status_file).exists():
-            if is_completed(self.dir) or is_failed(self.dir):
-                self.pbar.n = 100 if is_completed(self.dir) else 0
+        if self.job.has_status:
+            if self.job.is_completed or self.job.is_failed:
+                self.pbar.n = 100 if self.job.is_completed else 0
                 self.pbar.refresh()
                 self.finished = True
                 return
-            if not is_running(self.dir):
+            if not self.job.is_running:
                 return
 
         lines = self.get_lines()
