@@ -2,8 +2,10 @@ from pathlib import Path
 
 from .config import cfg
 from .ids import ImasHandle
-from .jetto import JettoSystem
-from .models import AbstractSystem, WorkDirectory
+from .jettoduqtools import JettoDuqtoolsSystem
+from .jettopythontools import JettoPythonToolsSystem
+from .models import AbstractSystem, Job, WorkDirectory
+from .schema import JettoVar
 
 
 class DummySystem(AbstractSystem):
@@ -18,6 +20,10 @@ class DummySystem(AbstractSystem):
                         template_drc: Path):
         pass
 
+    @staticmethod
+    def submit_job(job: Job):
+        pass
+
     @staticmethod
     def copy_from_template(source_drc: Path, target_drc: Path):
         pass
@@ -30,6 +36,10 @@ class DummySystem(AbstractSystem):
     def update_imas_locations(run: Path, inp, out):
         pass
 
+    @staticmethod
+    def set_jetto_variable(run: Path, key: str, value, variable: JettoVar):
+        pass
+
 
 def get_system():
     """get_system.
@@ -37,8 +47,10 @@ def get_system():
     Get the system to do operations with TODO make it a variable, not a
     function
     """
-    if (cfg.system == 'jetto'):
-        return JettoSystem
+    if (cfg.system in ['jetto', 'jetto-duqtools']):
+        return JettoDuqtoolsSystem
+    elif (cfg.system in ['jetto-pythontools']):
+        return JettoPythonToolsSystem
     elif (cfg.system == 'dummy'):
         return DummySystem
     else:
